yakumo.nova.v2.flavor

Package yakumo :: Package nova :: Package v2 :: Module flavor |
[hide private]
[frames] | no frames]

# Module flavor

source code

Resource class and its manager for flavors in Compute API v2

Classes | [hide private]
| Resource Resource class for flavors in Compute API v2
| Manager Manager class for flavors in Compute API v2

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.nova.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('ram', 'ra
      m', mapper.Noop), ('vcpus', 'vcpus', mapper.Noop), ('disk', 'disk', ma
      pper.Noop), ('ephemeral', 'OS-FLV-EXT-DATA:ephemeral', mapper.Noop), (
      'swap', 'swap', mapper.Noop), ('rxtx_factor', 'rxtx_factor', mapper.No
      op), ('is_public', 'os-flavor-access:is_public', mapper.Noop),]